@@ -8,16 +8,17 @@ use std::{
 };
 
 use crate::{
-    color::{AnsiColor, Color},
+    ansi::{ANSIBuf, ANSIFmt},
     colors::Colors,
-    config::{AlignmentHorizontal, AlignmentVertical, Indent, Position, Sides},
+    config::{
+        spanned::{Offset, SpannedConfig},
+        AlignmentHorizontal, AlignmentVertical, Formatting, Indent, Position, Sides,
+    },
     dimension::Dimension,
-    records::Records,
-    util::string::{count_lines, get_lines, string_width, string_width_multiline, Lines},
+    records::{IntoRecords, Records},
+    util::string::{count_lines, get_line_width, get_lines, get_text_width, Lines},
 };
 
-use crate::config::spanned::{Formatting, Offset, SpannedConfig};
-
 /// Grid provides a set of methods for building a text-based table.
 #[derive(Debug, Clone)]
 pub struct Grid<R, D, G, C> {
@@ -44,6 +45,7 @@ impl<R, D, G, C> Grid<R, D, G, C> {
     pub fn build<F>(self, mut f: F) -> fmt::Result
     where
         R: Records,
+        <R::Iter as IntoRecords>::Cell: AsRef<str>,
         D: Dimension,
         C: Colors,
         G: Borrow<SpannedConfig>,
@@ -64,6 +66,7 @@ impl<R, D, G, C> Grid<R, D, G, C> {
     pub fn to_string(self) -> String
     where
         R: Records,
+        <R::Iter as IntoRecords>::Cell: AsRef<str>,
         D: Dimension,
         G: Borrow<SpannedConfig>,
         C: Colors,
@@ -74,13 +77,20 @@ impl<R, D, G, C> Grid<R, D, G, C> {
     }
 }
 
-fn print_grid<F: Write, R: Records, D: Dimension, C: Colors>(
+fn print_grid<F, R, D, C>(
     f: &mut F,
     records: R,
     cfg: &SpannedConfig,
     dimension: &D,
     colors: &C,
-) -> fmt::Result {
+) -> fmt::Result
+where
+    F: Write,
+    R: Records,
+    <R::Iter as IntoRecords>::Cell: AsRef<str>,
+    D: Dimension,
+    C: Colors,
+{
     // spanned version is a bit more complex and 'supposedly' slower,
     // because spans are considered to be not a general case we are having 2 versions
     let grid_has_spans = cfg.has_column_spans() || cfg.has_row_spans();
@@ -91,13 +101,20 @@ fn print_grid<F: Write, R: Records, D: Dimension, C: Colors>(
     }
 }
 
-fn print_grid_general<F: Write, R: Records, D: Dimension, C: Colors>(
+fn print_grid_general<F, R, D, C>(
     f: &mut F,
     records: R,
     cfg: &SpannedConfig,
     dims: &D,
     colors: &C,
-) -> fmt::Result {
+) -> fmt::Result
+where
+    F: Write,
+    R: Records,
+    <R::Iter as IntoRecords>::Cell: AsRef<str>,
+    D: Dimension,
+    C: Colors,
+{
     let count_columns = records.count_columns();
 
     let mut totalw = None;
@@ -162,12 +179,7 @@ fn print_grid_general<F: Write, R: Records, D: Dimension, C: Colors>(
             buf.clear();
         }
 
-        if height == 0 && !has_horizontal {
-            is_prev_row_skipped = true;
-        } else {
-            is_prev_row_skipped = false;
-        }
-
+        is_prev_row_skipped = height == 0 && !has_horizontal;
         line += height;
         row += 1;
     }
@@ -260,21 +272,21 @@ where
     print_margin_left(f, cfg, line, totalh)?;
 
     for (col, cell) in columns.enumerate() {
-        let pos = (row, col);
+        let pos = (row, col).into();
         let width = dims.get_width(col);
         let color = colors.get_color(pos);
         print_vertical_char(f, cfg, pos, 0, 1, shape.1)?;
         print_single_line_column(f, cell.as_ref(), cfg, width, color, pos)?;
     }
 
-    print_vertical_char(f, cfg, (row, shape.1), 0, 1, shape.1)?;
+    print_vertical_char(f, cfg, (row, shape.1).into(), 0, 1, shape.1)?;
 
     print_margin_right(f, cfg, line, totalh)?;
 
     Ok(())
 }
 
-fn print_single_line_column<F: Write, C: Color>(
+fn print_single_line_column<F: Write, C: ANSIFmt>(
     f: &mut F,
     text: &str,
     cfg: &SpannedConfig,
@@ -282,19 +294,20 @@ fn print_single_line_column<F: Write, C: Color>(
     color: Option<&C>,
     pos: Position,
 ) -> fmt::Result {
-    let pos = pos.into();
     let pad = cfg.get_padding(pos);
     let pad_color = cfg.get_padding_color(pos);
     let fmt = cfg.get_formatting(pos);
+    let space = cfg.get_justification(pos);
+    let space_color = cfg.get_justification_color(pos);
 
     let (text, text_width) = if fmt.horizontal_trim && !text.is_empty() {
         let text = string_trim(text);
-        let width = string_width(&text);
+        let width = get_line_width(&text);
 
         (text, width)
     } else {
         let text = Cow::Borrowed(text);
-        let width = string_width_multiline(&text);
+        let width = get_text_width(&text);
 
         (text, width)
     };
@@ -305,9 +318,9 @@ fn print_single_line_column<F: Write, C: Color>(
 
     print_padding(f, &pad.left, pad_color.left.as_ref())?;
 
-    repeat_char(f, ' ', left)?;
+    print_indent(f, space, left, space_color)?;
     print_text(f, &text, color)?;
-    repeat_char(f, ' ', right)?;
+    print_indent(f, space, right, space_color)?;
 
     print_padding(f, &pad.right, pad_color.right.as_ref())?;
 
@@ -315,7 +328,7 @@ fn print_single_line_column<F: Write, C: Color>(
 }
 
 #[allow(clippy::too_many_arguments)]
-fn print_columns_lines<T, F: Write, C: Color>(
+fn print_columns_lines<T, F: Write, C: ANSIFmt>(
     f: &mut F,
     buf: &mut [Cell<T, C>],
     height: usize,
@@ -331,11 +344,11 @@ fn print_columns_lines<T, F: Write, C: Color>(
         print_margin_left(f, cfg, exact_line, totalh)?;
 
         for (col, cell) in buf.iter_mut().enumerate() {
-            print_vertical_char(f, cfg, (row, col), i, height, shape.1)?;
+            print_vertical_char(f, cfg, (row, col).into(), i, height, shape.1)?;
             cell.display(f)?;
         }
 
-        print_vertical_char(f, cfg, (row, shape.1), i, height, shape.1)?;
+        print_vertical_char(f, cfg, (row, shape.1).into(), i, height, shape.1)?;
 
         print_margin_right(f, cfg, exact_line, totalh)?;
 
@@ -362,7 +375,7 @@ fn collect_columns<'a, I, D, C>(
     D: Dimension,
 {
     let iter = iter.enumerate().map(|(col, cell)| {
-        let pos = (row, col);
+        let pos = (row, col).into();
         let width = dimension.get_width(col);
         let color = colors.get_color(pos);
         Cell::new(cell, width, height, cfg, color, pos)
@@ -379,14 +392,14 @@ fn print_split_line<F: Write, D: Dimension>(
     shape: (usize, usize),
 ) -> fmt::Result {
     let mut used_color = None;
-    print_vertical_intersection(f, cfg, (row, 0), shape, &mut used_color)?;
+    print_vertical_intersection(f, cfg, (row, 0).into(), shape, &mut used_color)?;
 
     for col in 0..shape.1 {
         let width = dimension.get_width(col);
 
         // general case
         if width > 0 {
-            let pos = (row, col);
+            let pos = (row, col).into();
             let main = cfg.get_horizontal(pos, shape.0);
             match main {
                 Some(c) => {
@@ -398,23 +411,30 @@ fn print_split_line<F: Write, D: Dimension>(
             }
         }
 
-        print_vertical_intersection(f, cfg, (row, col + 1), shape, &mut used_color)?;
+        print_vertical_intersection(f, cfg, (row, col + 1).into(), shape, &mut used_color)?;
     }
 
     if let Some(clr) = used_color.take() {
-        clr.fmt_suffix(f)?;
+        clr.fmt_ansi_suffix(f)?;
     }
 
     Ok(())
 }
 
-fn print_grid_spanned<F: Write, R: Records, D: Dimension, C: Colors>(
+fn print_grid_spanned<F, R, D, C>(
     f: &mut F,
     records: R,
     cfg: &SpannedConfig,
     dims: &D,
     colors: &C,
-) -> fmt::Result {
+) -> fmt::Result
+where
+    F: Write,
+    R: Records,
+    <R::Iter as IntoRecords>::Cell: AsRef<str>,
+    D: Dimension,
+    C: Colors,
+{
     let count_columns = records.count_columns();
 
     let total_width = total_width(cfg, dims, count_columns);
@@ -493,7 +513,7 @@ fn print_grid_spanned<F: Write, R: Records, D: Dimension, C: Colors>(
     Ok(())
 }
 
-fn print_split_line_spanned<S, F: Write, D: Dimension, C: Color>(
+fn print_split_line_spanned<S, F: Write, D: Dimension, C: ANSIFmt>(
     f: &mut F,
     buf: &mut BTreeMap<usize, (Cell<S, C>, usize, usize)>,
     cfg: &SpannedConfig,
@@ -502,10 +522,10 @@ fn print_split_line_spanned<S, F: Write, D: Dimension, C: Color>(
     shape: (usize, usize),
 ) -> fmt::Result {
     let mut used_color = None;
-    print_vertical_intersection(f, cfg, (row, 0), shape, &mut used_color)?;
+    print_vertical_intersection(f, cfg, (row, 0).into(), shape, &mut used_color)?;
 
     for col in 0..shape.1 {
-        let pos = (row, col);
+        let pos = (row, col).into();
         if cfg.is_cell_covered_by_both_spans(pos) {
             continue;
         }
@@ -521,7 +541,7 @@ fn print_split_line_spanned<S, F: Write, D: Dimension, C: Color>(
 
             // We need to use a correct right split char.
             let original_row = closest_visible_row(cfg, pos).unwrap();
-            if let Some(span) = cfg.get_column_span((original_row, col)) {
+            if let Some(span) = cfg.get_column_span((original_row, col).into()) {
                 col += span - 1;
             }
         } else if width > 0 {
@@ -537,11 +557,11 @@ fn print_split_line_spanned<S, F: Write, D: Dimension, C: Color>(
             }
         }
 
-        print_vertical_intersection(f, cfg, (row, col + 1), shape, &mut used_color)?;
+        print_vertical_intersection(f, cfg, (row, col + 1).into(), shape, &mut used_color)?;
     }
 
     if let Some(clr) = used_color.take() {
-        clr.fmt_suffix(f)?;
+        clr.fmt_ansi_suffix(f)?;
     }
 
     Ok(())
@@ -552,8 +572,12 @@ fn print_vertical_intersection<'a, F: fmt::Write>(
     cfg: &'a SpannedConfig,
     pos: Position,
     shape: (usize, usize),
-    used_color: &mut Option<&'a AnsiColor<'static>>,
+    used_color: &mut Option<&'a ANSIBuf>,
 ) -> fmt::Result {
+    if !cfg.has_vertical(pos.col(), shape.1) {
+        return Ok(());
+    }
+
     match cfg.get_intersection(pos, shape) {
         Some(c) => {
             let clr = cfg.get_intersection_color(pos, shape);
@@ -601,7 +625,7 @@ where
                 continue;
             }
 
-            let pos = (row, col);
+            let pos = (row, col).into();
             let rowspan = cfg.get_row_span(pos).unwrap_or(1);
             if rowspan < 2 {
                 continue;
@@ -647,7 +671,7 @@ where
             continue;
         }
 
-        let pos = (row, col);
+        let pos = (row, col).into();
         let colspan = cfg.get_column_span(pos).unwrap_or(1);
         skip = colspan - 1;
 
@@ -677,11 +701,18 @@ where
         print_margin_left(f, cfg, exact_line, totalh)?;
 
         for (&col, (cell, _, _)) in buf.iter_mut() {
-            print_vertical_char(f, cfg, (row, col), cell_line, this_height, shape.1)?;
+            print_vertical_char(f, cfg, (row, col).into(), cell_line, this_height, shape.1)?;
             cell.display(f)?;
         }
 
-        print_vertical_char(f, cfg, (row, shape.1), cell_line, this_height, shape.1)?;
+        print_vertical_char(
+            f,
+            cfg,
+            (row, shape.1).into(),
+            cell_line,
+            this_height,
+            shape.1,
+        )?;
 
         print_margin_right(f, cfg, exact_line, totalh)?;
 
@@ -704,7 +735,7 @@ fn print_horizontal_border<F: Write>(
     pos: Position,
     width: usize,
     c: char,
-    used_color: &Option<&AnsiColor<'static>>,
+    used_color: &Option<&ANSIBuf>,
 ) -> fmt::Result {
     if !cfg.is_overridden_horizontal(pos) {
         return repeat_char(f, c, width);
@@ -715,16 +746,16 @@ fn print_horizontal_border<F: Write>(
         match cfg.lookup_horizontal_color(pos, i, width) {
             Some(color) => match used_color {
                 Some(clr) => {
-                    clr.fmt_suffix(f)?;
-                    color.fmt_prefix(f)?;
+                    clr.fmt_ansi_suffix(f)?;
+                    color.fmt_ansi_prefix(f)?;
                     f.write_char(c)?;
-                    color.fmt_suffix(f)?;
-                    clr.fmt_prefix(f)?;
+                    color.fmt_ansi_suffix(f)?;
+                    clr.fmt_ansi_prefix(f)?;
                 }
                 None => {
-                    color.fmt_prefix(f)?;
+                    color.fmt_ansi_prefix(f)?;
                     f.write_char(c)?;
-                    color.fmt_suffix(f)?;
+                    color.fmt_ansi_suffix(f)?;
                 }
             },
             _ => f.write_char(c)?,
@@ -742,8 +773,9 @@ struct Cell<T, C> {
     alignh: AlignmentHorizontal,
     fmt: Formatting,
     pad: Sides<Indent>,
-    pad_color: Sides<Option<AnsiColor<'static>>>,
+    pad_color: Sides<Option<ANSIBuf>>,
     color: Option<C>,
+    justification: (char, Option<ANSIBuf>),
 }
 
 impl<T, C> Cell<T, C>
@@ -758,11 +790,15 @@ where
         color: Option<C>,
         pos: Position,
     ) -> Cell<T, C> {
-        let fmt = *cfg.get_formatting(pos.into());
-        let pad = cfg.get_padding(pos.into());
-        let pad_color = cfg.get_padding_color(pos.into()).clone();
-        let alignh = *cfg.get_alignment_horizontal(pos.into());
-        let alignv = *cfg.get_alignment_vertical(pos.into());
+        let fmt = cfg.get_formatting(pos);
+        let pad = cfg.get_padding(pos);
+        let pad_color = cfg.get_padding_color(pos).clone();
+        let alignh = *cfg.get_alignment_horizontal(pos);
+        let alignv = *cfg.get_alignment_vertical(pos);
+        let justification = (
+            cfg.get_justification(pos),
+            cfg.get_justification_color(pos).cloned(),
+        );
 
         let (count_lines, skip) = if fmt.vertical_trim {
             let (len, top, _) = count_empty_lines(text.as_ref());
@@ -775,7 +811,7 @@ where
 
         let mut indent_left = None;
         if !fmt.allow_lines_alignment {
-            let text_width = get_text_width(text.as_ref(), fmt.horizontal_trim);
+            let text_width = text_width(text.as_ref(), fmt.horizontal_trim);
             let available = width - pad.left.size - pad.right.size;
             indent_left = Some(calculate_indent(alignh, text_width, available).0);
         }
@@ -795,13 +831,14 @@ where
             pad,
             pad_color,
             color,
+            justification,
         }
     }
 }
 
 impl<T, C> Cell<T, C>
 where
-    C: Color,
+    C: ANSIFmt,
 {
     fn display<F: Write>(&mut self, f: &mut F) -> fmt::Result {
         if self.indent_top > 0 {
@@ -825,7 +862,7 @@ where
             line
         };
 
-        let line_width = string_width(&line);
+        let line_width = get_line_width(&line);
         let available_width = self.width - self.pad.left.size - self.pad.right.size;
 
         let (left, right) = if self.fmt.allow_lines_alignment {
@@ -835,11 +872,14 @@ where
             (left, available_width - line_width - left)
         };
 
+        let (justification, justification_color) =
+            (self.justification.0, self.justification.1.as_ref());
+
         print_padding(f, &self.pad.left, self.pad_color.left.as_ref())?;
 
-        repeat_char(f, ' ', left)?;
+        print_indent(f, justification, left, justification_color)?;
         print_text(f, &line, self.color.as_ref())?;
-        repeat_char(f, ' ', right)?;
+        print_indent(f, justification, right, justification_color)?;
 
         print_padding(f, &self.pad.right, self.pad_color.right.as_ref())?;
 
@@ -884,39 +924,39 @@ impl<C> LinesIter<C> {
     }
 }
 
-fn print_text<F: Write>(f: &mut F, text: &str, clr: Option<impl Color>) -> fmt::Result {
+fn print_text<F: Write>(f: &mut F, text: &str, clr: Option<impl ANSIFmt>) -> fmt::Result {
     match clr {
         Some(color) => {
-            color.fmt_prefix(f)?;
+            color.fmt_ansi_prefix(f)?;
             f.write_str(text)?;
-            color.fmt_suffix(f)
+            color.fmt_ansi_suffix(f)
         }
         None => f.write_str(text),
     }
 }
 
-fn prepare_coloring<'a, 'b, F: Write>(
+fn prepare_coloring<'a, F: Write>(
     f: &mut F,
-    clr: Option<&'a AnsiColor<'b>>,
-    used_color: &mut Option<&'a AnsiColor<'b>>,
+    clr: Option<&'a ANSIBuf>,
+    used_color: &mut Option<&'a ANSIBuf>,
 ) -> fmt::Result {
     match clr {
         Some(clr) => match used_color.as_mut() {
             Some(used_clr) => {
                 if **used_clr != *clr {
-                    used_clr.fmt_suffix(f)?;
-                    clr.fmt_prefix(f)?;
+                    used_clr.fmt_ansi_suffix(f)?;
+                    clr.fmt_ansi_prefix(f)?;
                     *used_clr = clr;
                 }
             }
             None => {
-                clr.fmt_prefix(f)?;
+                clr.fmt_ansi_prefix(f)?;
                 *used_color = Some(clr);
             }
         },
         None => {
             if let Some(clr) = used_color.take() {
-                clr.fmt_suffix(f)?
+                clr.fmt_ansi_suffix(f)?
             }
         }
     }
@@ -983,16 +1023,18 @@ fn print_vertical_char<F: Write>(
     };
 
     let symbol = cfg
-        .is_overridden_vertical(pos)
-        .then(|| cfg.lookup_vertical_char(pos, line, count_lines))
-        .flatten()
+        .lookup_vertical_char(pos, line, count_lines)
         .unwrap_or(symbol);
 
-    match cfg.get_vertical_color(pos, count_columns) {
+    let color = cfg
+        .get_vertical_color(pos, count_columns)
+        .or_else(|| cfg.lookup_vertical_color(pos, line, count_lines));
+
+    match color {
         Some(clr) => {
-            clr.fmt_prefix(f)?;
+            clr.fmt_ansi_prefix(f)?;
             f.write_char(symbol)?;
-            clr.fmt_suffix(f)?;
+            clr.fmt_ansi_suffix(f)?;
         }
         None => f.write_char(symbol)?,
     }
@@ -1046,7 +1088,7 @@ fn print_margin_vertical<F: Write>(
     f: &mut F,
     indent: Indent,
     offset: Offset,
-    color: Option<&AnsiColor<'_>>,
+    color: Option<&ANSIBuf>,
     line: usize,
     height: Option<usize>,
 ) -> fmt::Result {
@@ -1089,7 +1131,7 @@ fn print_indent_lines<F: Write>(
     f: &mut F,
     indent: &Indent,
     offset: &Offset,
-    color: Option<&AnsiColor<'_>>,
+    color: Option<&ANSIBuf>,
     width: usize,
 ) -> fmt::Result {
     if indent.size == 0 {
@@ -1126,57 +1168,50 @@ fn print_indent_lines<F: Write>(
     Ok(())
 }
 
-fn print_padding<F: Write>(f: &mut F, pad: &Indent, color: Option<&AnsiColor<'_>>) -> fmt::Result {
+fn print_padding<F: Write>(f: &mut F, pad: &Indent, color: Option<&ANSIBuf>) -> fmt::Result {
     print_indent(f, pad.fill, pad.size, color)
 }
 
 fn print_padding_n<F: Write>(
     f: &mut F,
     pad: &Indent,
-    color: Option<&AnsiColor<'_>>,
+    color: Option<&ANSIBuf>,
     n: usize,
 ) -> fmt::Result {
     print_indent(f, pad.fill, n, color)
 }
 
-fn print_indent<F: Write>(
-    f: &mut F,
-    c: char,
-    n: usize,
-    color: Option<&AnsiColor<'_>>,
-) -> fmt::Result {
+fn print_indent<F: Write>(f: &mut F, c: char, n: usize, color: Option<&ANSIBuf>) -> fmt::Result {
+    if n == 0 {
+        return Ok(());
+    }
+
     match color {
         Some(color) => {
-            color.fmt_prefix(f)?;
+            color.fmt_ansi_prefix(f)?;
             repeat_char(f, c, n)?;
-            color.fmt_suffix(f)
+            color.fmt_ansi_suffix(f)
         }
         None => repeat_char(f, c, n),
     }
 }
 
-fn range_width(
-    cfg: &SpannedConfig,
-    d: impl Dimension,
-    start: usize,
-    end: usize,
-    max: usize,
-) -> usize {
+fn range_width<D>(cfg: &SpannedConfig, dims: D, start: usize, end: usize, max: usize) -> usize
+where
+    D: Dimension,
+{
     let count_borders = count_verticals_in_range(cfg, start, end, max);
-    let range_width = (start..end).map(|col| d.get_width(col)).sum::<usize>();
+    let range_width = (start..end).map(|col| dims.get_width(col)).sum::<usize>();
 
     count_borders + range_width
 }
 
-fn range_height(
-    cfg: &SpannedConfig,
-    d: impl Dimension,
-    from: usize,
-    end: usize,
-    max: usize,
-) -> usize {
+fn range_height<D>(cfg: &SpannedConfig, dims: D, from: usize, end: usize, max: usize) -> usize
+where
+    D: Dimension,
+{
     let count_borders = count_horizontals_in_range(cfg, from, end, max);
-    let range_width = (from..end).map(|col| d.get_height(col)).sum::<usize>();
+    let range_width = (from..end).map(|col| dims.get_height(col)).sum::<usize>();
 
     count_borders + range_width
 }
@@ -1197,14 +1232,14 @@ fn count_verticals_in_range(cfg: &SpannedConfig, start: usize, end: usize, max:
 fn closest_visible_row(cfg: &SpannedConfig, mut pos: Position) -> Option<usize> {
     loop {
         if cfg.is_cell_visible(pos) {
-            return Some(pos.0);
+            return Some(pos.row());
         }
 
-        if pos.0 == 0 {
+        if pos.row() == 0 {
             return None;
         }
 
-        pos.0 -= 1;
+        pos -= (1, 0);
     }
 }
 
@@ -1218,12 +1253,12 @@ fn convert_count_rows(row: usize, is_last: bool) -> usize {
 
 /// Trims a string.
 fn string_trim(text: &str) -> Cow<'_, str> {
-    #[cfg(feature = "color")]
+    #[cfg(feature = "ansi")]
     {
         ansi_str::AnsiStr::ansi_trim(text)
     }
 
-    #[cfg(not(feature = "color"))]
+    #[cfg(not(feature = "ansi"))]
     {
         text.trim().into()
     }
@@ -1273,53 +1308,21 @@ fn count_empty_lines(cell: &str) -> (usize, usize, usize) {
     (len, top, bottom)
 }
 
-fn get_text_width(text: &str, trim: bool) -> usize {
+fn text_width(text: &str, trim: bool) -> usize {
     if trim {
         get_lines(text)
-            .map(|line| string_width(line.trim()))
+            .map(|line| get_line_width(line.trim()))
             .max()
             .unwrap_or(0)
     } else {
-        string_width_multiline(text)
+        get_text_width(text)
     }
 }
 
 #[cfg(test)]
 mod tests {
-    // use crate::util::string_width;
-
     use super::*;
 
-    // #[test]
-    // fn horizontal_alignment_test() {
-    //     use std::fmt;
-
-    //     struct F<'a>(&'a str, AlignmentHorizontal, usize);
-
-    //     impl fmt::Display for F<'_> {
-    //         fn fmt(&self, f: &mut impl fmt::Write) -> fmt::Result {
-    //             let (left, right) = calculate_indent(self.1, string_width(self.0), self.2);
-    //             print_text_formatted(f, &self.0, 4, Option::<&AnsiColor<'_>>::None)
-    //         }
-    //     }
-
-    //     assert_eq!(F("AAA", AlignmentHorizontal::Right, 4).to_string(), " AAA");
-    //     assert_eq!(F("AAA", AlignmentHorizontal::Left, 4).to_string(), "AAA ");
-    //     assert_eq!(F("AAA", AlignmentHorizontal::Center, 4).to_string(), "AAA ");
-    //     assert_eq!(F("🎩", AlignmentHorizontal::Center, 4).to_string(), " 🎩 ");
-    //     assert_eq!(F("🎩", AlignmentHorizontal::Center, 3).to_string(), "🎩 ");
-
-    //     #[cfg(feature = "color")]
-    //     {
-    //         use owo_colors::OwoColorize;
-    //         let text = "Colored Text".red().to_string();
-    //         assert_eq!(
-    //             F(&text, AlignmentHorizontal::Center, 15).to_string(),
-    //             format!(" {}  ", text)
-    //         );
-    //     }
-    // }
-
     #[test]
     fn vertical_alignment_test() {
         use AlignmentVertical::*;
